"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.FinanceApplicationForm = void 0;
const react_native_1 = require("react-native");
const Yup = __importStar(require("yup"));
const react_1 = __importStar(require("react"));
const data_1 = require("../data");
const react_native_paper_1 = require("react-native-paper");
const hooks_1 = require("../hooks");
const helpers_1 = require("../helpers");
const query_string_1 = __importDefault(require("query-string"));
const react_native_flash_message_1 = require("react-native-flash-message");
const Gutter_1 = require("../component/Gutter");
const UploadAttachment_1 = require("../component/molecules/UploadAttachment");
const formik_1 = require("formik");
const context_1 = require("../context/context");
const segment_1 = __importDefault(require("../utils/segment"));
const segmentEvents_1 = require("../data/segmentEvents");
const constant_1 = require("../data/constant");
const FieldTextInput_1 = require("./molecules/FieldTextInput");
const validationSchema = Yup.object().shape({
    required_financing: Yup.number()
        .required("Amount is required")
        .min(1, "Amount must be greater than zero"),
});
const FinanceApplicationForm = ({ loanId, data, onSuccess }) => {
    const [prediction, setPrediction] = (0, react_1.useState)();
    const theme = (0, react_native_paper_1.useTheme)();
    const { axiosInstance, info, userDetail } = (0, context_1.useLMS)();
    const { setAppError } = (0, hooks_1.useAppErrors)();
    const calculateAmount = async (tenure, principal) => {
        try {
            const response = await axiosInstance.post("/v1/external-lending/sme/loans/predict", {
                user_id: userDetail?.kyb.id,
                tenure,
                principal_amount: principal,
            });
            setPrediction(response.data.balances);
        }
        catch (e) {
            setAppError(e.response.data);
        }
    };
    const onSuccessResponse = (response, action, value) => {
        const documentLength = (0, helpers_1.arrayLength)(value);
        onSuccess?.(response);
        action.resetForm({
            values: data_1.CREATE_LOAN,
        });
        setPrediction(undefined);
        (0, react_native_flash_message_1.showMessage)({
            message: "Successfully Submitted",
            type: "success",
        });
        segment_1.default.track(segmentEvents_1.SEGMENT_EVENTS.COMPLETE_FINANCE_APPLICATION_FORM, {
            ...(0, helpers_1.removeArrays)(value),
            ...constant_1.PLATFORM,
            attached_documents_count: documentLength,
        });
    };
    const onSubmit = async (value, action) => {
        try {
            action.setSubmitting(true);
            if (!data) {
                const { data: response } = await axiosInstance.post(`/v1/external-lending/sme/loans?${query_string_1.default.stringify(info || {})}`, {
                    ...value,
                });
                onSuccessResponse(response, action, value);
            }
            else {
                const { data: response } = await axiosInstance.patch(`/v1/external-lending/sme/loans/${loanId}`, {
                    ...value,
                    ...info,
                });
                onSuccessResponse(response, action, value);
            }
        }
        catch (e) {
            setAppError(e?.response?.data);
        }
        finally {
            action.setSubmitting(false);
        }
    };
    return (react_1.default.createElement(react_native_1.View, { style: styles.container },
        react_1.default.createElement(formik_1.Formik, { initialValues: data || data_1.CREATE_LOAN, validationSchema: validationSchema, onSubmit: onSubmit }, ({ values, handleSubmit, isSubmitting, isValid, dirty }) => (react_1.default.createElement(react_1.default.Fragment, null,
            react_1.default.createElement(react_native_1.View, null,
                react_1.default.createElement(react_native_paper_1.Text, { variant: "headlineSmall", style: { fontWeight: "500" } }, "Apply for Financing"),
                react_1.default.createElement(Gutter_1.Gutter, { spacing: 0.1 }),
                react_1.default.createElement(react_native_paper_1.Text, { variant: "bodyLarge" }, "Please provide us details of your inventory/purchase order/invoice."),
                react_1.default.createElement(Gutter_1.Gutter, { spacing: 1.5 }),
                react_1.default.createElement(UploadAttachment_1.UploadAttachment, { buttonLabel: "ATTACH DOCUMENT", name: "invoice_data", title: "Documents (invoice/purchase order/inventory)" }),
                react_1.default.createElement(Gutter_1.Gutter, { spacing: 0.3 }),
                react_1.default.createElement(FieldTextInput_1.FieldTextInput, { title: "Financing Amount (PKR)", name: "required_financing", placeholder: "0", onBlur: (e) => calculateAmount(values?.tenure || "0", e) }),
                react_1.default.createElement(Gutter_1.Gutter, { spacing: 0.3 }),
                react_1.default.createElement(FieldTextInput_1.FieldTextInput, { title: "Financing Term (days)", name: "tenure", placeholder: "0", onChange: (e) => calculateAmount(e, values.required_financing) }),
                react_1.default.createElement(Gutter_1.Gutter, null),
                react_1.default.createElement(react_native_paper_1.Text, { variant: "titleSmall", style: styles.label }, "Principal Amount"),
                react_1.default.createElement(Gutter_1.Gutter, { spacing: 0.1 }),
                react_1.default.createElement(react_native_paper_1.Text, { variant: "bodyLarge" },
                    "PKR",
                    " ",
                    (parseFloat(`${values.required_financing}`) || 0).toLocaleString()),
                react_1.default.createElement(Gutter_1.Gutter, null),
                react_1.default.createElement(react_native_paper_1.Text, { variant: "titleSmall", style: styles.label }, "Total Markup"),
                react_1.default.createElement(react_native_paper_1.Text, { variant: "bodyLarge" },
                    "PKR ",
                    prediction?.markupPending),
                react_1.default.createElement(Gutter_1.Gutter, { spacing: 0.7 }),
                react_1.default.createElement(react_native_paper_1.Divider, null),
                react_1.default.createElement(Gutter_1.Gutter, { spacing: 0.7 }),
                react_1.default.createElement(react_native_paper_1.Text, { variant: "titleSmall" }, "Total Net Payment Due"),
                react_1.default.createElement(react_native_paper_1.Text, { variant: "titleSmall", style: styles.label },
                    "PKR",
                    " ",
                    ((parseFloat(`${prediction?.amountPending}`) || 0) +
                        (prediction?.markupPending || 0)).toLocaleString()),
                react_1.default.createElement(Gutter_1.Gutter, { spacing: 2 }),
                react_1.default.createElement(react_native_paper_1.Button, { style: styles.button, mode: "contained", onPress: () => handleSubmit(), disabled: isSubmitting || !isValid || !dirty }, "Submit")))))));
};
exports.FinanceApplicationForm = FinanceApplicationForm;
const styles = react_native_1.StyleSheet.create({
    container: {
        minHeight: 3000,
        display: "flex",
        flex: 1,
        padding: 16,
    },
    label: { color: "rgb(124, 117, 126)" },
    scrollViewContent: {
        padding: 16,
    },
    attachment: {
        marginBottom: 10,
    },
    button: { borderRadius: 4 },
});
/*
  <Typography
    variant={'caption'}
    color={theme.palette.grey['700']}
  >
    Total Markup
  </Typography>
  <Typography variant={'body2'}>
    PKR {prediction?.markupPending}
  </Typography>
  <Gutter spacing={0.4} />
  <HorizontalBar />
  <Gutter spacing={0.4} />
  <Typography
    variant={'caption'}
    color={theme.palette.grey['700']}
  >
    Total Net Payment Due
  </Typography>
  <Typography variant={'body2'} fontWeight={600}>
    PKR{' '}
    {(
      (parseFloat(
        `${prediction?.amountPending}`
      ) || 0) +
      (prediction?.markupPending || 0)
    ).toLocaleString()}
  </Typography>
</Box>
<StyledRow>
  <StyledPrimaryButton
    variant={'outlined'}
    onClick={() => {
      //
    }}
    disabled={isSubmitting}
  >
    <PrimaryButtonWrapper>
      Cancel
    </PrimaryButtonWrapper>
  </StyledPrimaryButton>
  <Gutter gap={1} />
  <StyledPrimaryButton
    variant={'contained'}
    onClick={() => handleSubmit()}
    disabled={isSubmitting || !isValid}
  >
    <PrimaryButtonWrapper>
      Submit
    </PrimaryButtonWrapper>
  </StyledPrimaryButton>
</StyledRow>*/
