"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.UploadAttachment = void 0;
const react_1 = __importStar(require("react"));
const react_native_1 = require("react-native");
const AntDesign_1 = __importDefault(require("react-native-vector-icons/AntDesign"));
const MaterialCommunityIcons_1 = __importDefault(require("react-native-vector-icons/MaterialCommunityIcons"));
const Feather_1 = __importDefault(require("react-native-vector-icons/Feather"));
const react_native_paper_1 = require("react-native-paper");
const formik_1 = require("formik");
const helpers_1 = require("../../helpers");
const react_native_action_sheet_1 = require("@expo/react-native-action-sheet");
const context_1 = require("../../context/context");
const react_native_image_crop_picker_1 = __importDefault(require("react-native-image-crop-picker"));
const react_native_flash_message_1 = require("react-native-flash-message");
const imageOption = {
    multiple: false,
    cropping: true,
    mediaType: 'photo',
    freeStyleCropEnabled: true,
};
const UploadAttachment = ({ name, disabled, title, buttonLabel, }) => {
    const [loading, setLoading] = (0, react_1.useState)(false);
    const [tempFile, setTempFile] = (0, react_1.useState)({ url: '', name: '' });
    const [, meta, helpers] = (0, formik_1.useField)(name);
    const { axiosInstance } = (0, context_1.useLMS)();
    const { showActionSheetWithOptions } = (0, react_native_action_sheet_1.useActionSheet)();
    const uploadADoc = (0, react_1.useCallback)(async (fileName) => {
        try {
            const { data } = await axiosInstance.get(`/v1/external-lending/sme/s3/presigned-url?file_name=${fileName}`);
            return data;
        }
        catch (error) {
            throw error.response.data;
        }
    }, [axiosInstance]);
    const onSuccessfulUpload = (0, react_1.useCallback)((uploadUrl, image) => {
        helpers.setValue([
            ...meta.value,
            {
                name: image.filename,
                size: image.size,
                resourceURL: uploadUrl,
            },
        ]);
        setTempFile({ url: '', name: '' });
    }, [helpers, meta.value]);
    const uploadToS3 = (0, react_1.useCallback)(async (uploadUrl, image) => {
        try {
            const response = await fetch(image.path);
            const blob = await response.blob();
            await fetch(uploadUrl, {
                method: 'PUT',
                body: blob,
                headers: {
                    'Content-Type': blob.type,
                },
            });
            (0, react_native_flash_message_1.showMessage)({ message: 'Successfully uploaded', type: 'success' });
            onSuccessfulUpload(uploadUrl, image);
        }
        catch (error) {
            (0, react_native_flash_message_1.showMessage)({ message: 'Something went wrong', type: 'danger' });
        }
    }, [onSuccessfulUpload]);
    const uploadImage = (0, react_1.useCallback)(async (image) => {
        try {
            setLoading(true);
            const res = await uploadADoc(image?.filename || 'untitled');
            await uploadToS3(res.putPresignedURL, image);
        }
        catch (e) {
            (0, react_native_flash_message_1.showMessage)({ message: 'Upload failed', type: 'danger' });
        }
        finally {
            setLoading(false);
        }
    }, [uploadADoc, uploadToS3]);
    const openActionSheet = (0, react_1.useCallback)(() => {
        const options = ['Open Gallery', 'Open Camera', 'Cancel'];
        const cancelButtonIndex = 2;
        showActionSheetWithOptions({
            options,
            cancelButtonIndex,
        }, buttonIndex => {
            if (buttonIndex === 0) {
                react_native_image_crop_picker_1.default.openPicker(imageOption).then(image => {
                    setTempFile({
                        url: image.path,
                        name: image.filename || 'untitled',
                    });
                    uploadImage(image);
                });
            }
            else if (buttonIndex === 1) {
                react_native_image_crop_picker_1.default.openCamera(imageOption).then(image => {
                    setTempFile({ url: image.path, name: image.filename || '' });
                });
            }
            helpers.setTouched(true);
        });
    }, [helpers, showActionSheetWithOptions, uploadImage]);
    return (react_1.default.createElement(react_native_1.View, { style: styles.container },
        react_1.default.createElement(react_native_1.View, { style: styles.row },
            react_1.default.createElement(react_native_paper_1.Text, { style: styles.title }, title),
            react_1.default.createElement(react_native_paper_1.Button, { style: styles.uploadButton, mode: "outlined", icon: buttonLabel ? undefined : () => react_1.default.createElement(Feather_1.default, { name: 'upload' }), onPress: () => {
                    openActionSheet();
                }, disabled: loading || disabled },
                react_1.default.createElement(react_native_paper_1.Text, { variant: 'bodyMedium' }, buttonLabel || 'Upload file'))),
        react_1.default.createElement(react_native_1.View, { style: styles.flex },
            meta.value.map((m) => (react_1.default.createElement(react_native_paper_1.Card, { key: m.resourceURL, style: styles.card, elevation: 0 },
                react_1.default.createElement(react_native_1.View, { style: styles.cardContent },
                    react_1.default.createElement(react_native_1.View, { style: styles.attachmentWrapper },
                        react_1.default.createElement(react_native_paper_1.Text, null, m.name),
                        react_1.default.createElement(react_native_paper_1.Text, { style: styles.caption },
                            (0, helpers_1.formatFileSize)(m.size),
                            " Completed")),
                    react_1.default.createElement(react_native_1.View, { style: styles.iconRow },
                        react_1.default.createElement(react_native_1.TouchableOpacity, { onPress: () => helpers.setValue((0, helpers_1.addOrRemoveArr)(meta.value, m)), disabled: loading || disabled },
                            react_1.default.createElement(MaterialCommunityIcons_1.default, { name: 'delete', color: 'rgba(0, 0, 0, 0.56)', size: 22 })),
                        react_1.default.createElement(AntDesign_1.default, { name: 'checkcircle', color: '#178D46', size: 22 })))))),
            (tempFile?.name || tempFile?.url) && (react_1.default.createElement(react_native_paper_1.Card, { style: styles.card, elevation: 0 },
                react_1.default.createElement(react_native_1.View, { style: styles.cardContent },
                    react_1.default.createElement(react_native_1.View, { style: styles.attachmentWrapper },
                        react_1.default.createElement(react_native_paper_1.Text, { numberOfLines: 1 }, `Attachment-${tempFile?.name}`),
                        react_1.default.createElement(react_native_paper_1.Text, { style: styles.caption }, "Uploading")),
                    react_1.default.createElement(react_native_1.View, null,
                        react_1.default.createElement(react_native_paper_1.ActivityIndicator, { color: '#178D46' }))))),
            meta.error && meta.touched && (react_1.default.createElement(react_native_paper_1.Text, { style: styles.errorText }, meta.error)))));
};
exports.UploadAttachment = UploadAttachment;
const styles = react_native_1.StyleSheet.create({
    attachmentWrapper: {
        width: '100%',
        maxWidth: '80%',
    },
    container: {
        width: '100%',
        marginBottom: 15,
    },
    row: {
        flexDirection: 'row',
        justifyContent: 'space-between',
        alignItems: 'center',
        flexWrap: 'wrap',
    },
    title: {
        fontWeight: '500',
    },
    flex: {
        width: '100%',
        flexDirection: 'column',
    },
    card: {
        width: '100%',
        padding: 10,
        justifyContent: 'center',
        backgroundColor: 'transparent',
        borderRadius: 4,
        borderWidth: 1,
        borderColor: '#DBDBDB',
        marginTop: 10,
    },
    cardContent: {
        flexDirection: 'row',
        justifyContent: 'space-between',
        alignItems: 'center',
        flexWrap: 'nowrap',
    },
    caption: {
        color: 'gray',
    },
    iconRow: {
        flex: 1,
        flexDirection: 'row',
        alignItems: 'center',
    },
    errorText: {
        color: 'red',
        marginTop: 10,
    },
    uploadButton: {
        borderRadius: 6,
    },
});
