"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.LoanList = void 0;
const react_1 = __importStar(require("react"));
const query_string_1 = __importDefault(require("query-string"));
const loan_1 = require("../typings/loan");
const context_1 = require("../context/context");
const hooks_1 = require("../hooks");
const Loanlist_1 = require("../data/Loanlist");
const react_native_1 = require("react-native");
const react_native_paper_1 = require("react-native-paper");
const react_native_picker_select_1 = __importDefault(require("react-native-picker-select"));
const segmentEvents_1 = require("../data/segmentEvents");
const segment_1 = __importDefault(require("../utils/segment"));
const loanItem_1 = require("../screen/components/loanItem");
const react_native_tab_view_1 = require("react-native-tab-view");
const ApplicationList_1 = require("../screen/components/ApplicationList");
const LoanList = ({ onPress }) => {
    const [search, setSearch] = (0, react_1.useState)('');
    const [filter, setFilter] = (0, react_1.useState)(loan_1.FilteredLoanStatus.ALL_LOANS);
    const [filteredData, setFilteredData] = (0, react_1.useState)([]);
    const { axiosInstance, info } = (0, context_1.useLMS)();
    const { setAppError } = (0, hooks_1.useAppErrors)();
    const theme = (0, react_native_paper_1.useTheme)();
    const layout = (0, react_native_1.useWindowDimensions)();
    const [index, setIndex] = (0, react_1.useState)(0);
    const [routes, setRoutes] = (0, react_1.useState)([
        { key: 'loan', title: 'Loan (0)' },
        { key: 'application', title: 'Application (0)' },
    ]);
    const getFilterArr = (0, react_1.useCallback)((arr) => {
        const ftc = arr.filter(f => f.display_id.toLowerCase().includes(search.toLowerCase()));
        return filter === loan_1.FilteredLoanStatus.ALL_LOANS
            ? ftc
            : ftc.filter(f => f.status.toLowerCase() === filter.toLowerCase());
    }, [filter, search]);
    const getAllLoans = (0, react_1.useCallback)(async () => {
        try {
            const { data } = await axiosInstance.get(`/v1/external-lending/sme/loans?${query_string_1.default.stringify(info || {})}`);
            setFilteredData(data.loans);
        }
        catch (e) {
            setAppError(e.response.data);
        }
    }, [info, axiosInstance, setAppError]);
    (0, react_1.useEffect)(() => {
        getAllLoans();
    }, [getAllLoans]);
    const onFilter = (text) => {
        setFilter(text);
        segment_1.default.track(index === 0
            ? segmentEvents_1.SEGMENT_EVENTS.CLICK_FILTER_LOANS_BY_STATUS
            : segmentEvents_1.SEGMENT_EVENTS.CLICK_SEARCH_APPLICATION, { loan_status_selected: text });
    };
    const loan = getFilterArr(filteredData.filter(item => Loanlist_1.APPLICATION_STATUS.includes(item.status)));
    const application = getFilterArr(filteredData.filter(item => !Loanlist_1.APPLICATION_STATUS.includes(item.status)));
    (0, react_1.useEffect)(() => {
        setRoutes([
            { key: 'loan', title: `Loan (${loan.length})` },
            { key: 'application', title: `Application (${application.length})` },
        ]);
    }, [loan.length, application.length]);
    const renderScene = (0, react_native_tab_view_1.SceneMap)({
        loan: () => (react_1.default.createElement(react_native_1.ScrollView, { style: styles.tabContent },
            react_1.default.createElement(loanItem_1.LoansTable, { dataSource: loan, onPress: onPress }))),
        application: () => (react_1.default.createElement(react_native_1.ScrollView, { style: styles.tabContent },
            react_1.default.createElement(ApplicationList_1.ApplicationTable, { dataSource: application, onPress: onPress }))),
    });
    return (react_1.default.createElement(react_native_1.View, { style: styles.container },
        react_1.default.createElement(react_native_1.View, { style: styles.searchContainer },
            react_1.default.createElement(react_native_paper_1.TextInput, { mode: "outlined", value: search, placeholder: 'Search', onChangeText: setSearch, style: styles.searchInput, onBlur: () => {
                    segment_1.default.track(index === 0
                        ? segmentEvents_1.SEGMENT_EVENTS.CLICK_SEARCH_LOAN
                        : segmentEvents_1.SEGMENT_EVENTS.CLICK_SEARCH_APPLICATION, { loan_id: search });
                } }),
            react_1.default.createElement(react_native_picker_select_1.default, { onValueChange: onFilter, style: pickerSelectStyles, items: Loanlist_1.FILTER_BY_STATUS },
                react_1.default.createElement(react_native_1.TouchableOpacity, { style: styles.filterButton },
                    react_1.default.createElement(react_native_paper_1.Text, null, "Filter")))),
        react_1.default.createElement(react_native_tab_view_1.TabView, { navigationState: { index, routes }, renderScene: renderScene, onIndexChange: setIndex, initialLayout: { width: layout.width }, renderTabBar: props => (react_1.default.createElement(react_native_tab_view_1.TabBar, { ...props, indicatorStyle: { backgroundColor: theme.colors.primary }, style: { backgroundColor: theme.colors.background }, labelStyle: {
                    color: '#000',
                } })) })));
};
exports.LoanList = LoanList;
const styles = react_native_1.StyleSheet.create({
    container: {
        flex: 1,
        minHeight: 900,
    },
    searchContainer: {
        flexDirection: 'row',
        alignItems: 'center',
        margin: 10,
    },
    searchInput: {
        flex: 1,
        marginRight: 10,
    },
    filterButton: {
        backgroundColor: '#DCE3E8',
        borderRadius: 5,
        alignItems: 'center',
        padding: 20,
        width: '100%',
        justifyContent: 'center',
    },
    tabs: {
        backgroundColor: '#fff',
        flex: 1,
    },
    tabContent: {
        flex: 1,
        backgroundColor: 'white',
        padding: 20,
    },
});
const pickerSelectStyles = {
    inputIOS: {
        fontSize: 16,
        paddingVertical: 16,
        paddingHorizontal: 10,
        borderWidth: 1,
        borderColor: 'gray',
        borderRadius: 4,
        color: 'black',
        paddingRight: 30,
        backgroundColor: 'white',
    },
    inputAndroid: {
        fontSize: 16,
        paddingVertical: 12,
        paddingHorizontal: 10,
        borderWidth: 0.5,
        borderColor: 'gray',
        borderRadius: 8,
        color: 'black',
        paddingRight: 30,
        backgroundColor: 'white',
    },
};
