"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.RepaymentModal = void 0;
const react_1 = __importStar(require("react"));
const react_native_1 = require("react-native");
const react_native_paper_1 = require("react-native-paper");
const formik_1 = require("formik");
const moment_1 = __importDefault(require("moment"));
const Yup = __importStar(require("yup"));
const query_string_1 = __importDefault(require("query-string"));
const context_1 = require("../context/context");
const hooks_1 = require("../hooks");
const typings_1 = require("../typings");
const segment_1 = __importDefault(require("../utils/segment"));
const segmentEvents_1 = require("../data/segmentEvents");
const react_native_flash_message_1 = require("react-native-flash-message");
const AntDesign_1 = __importDefault(require("react-native-vector-icons/AntDesign"));
const components_1 = require("../components");
const data_1 = require("../data");
const FieldDatePicker_1 = require("../components/molecules/FieldDatePicker");
const validationSchema = Yup.object().shape({
    amount: Yup.number()
        .required("Amount is required")
        .min(1, "Amount must be greater than zero")
        .test("maxPayment", (quantity, values) => {
        const { parent } = values;
        if (parent?.maxPayment < (quantity || 0)) {
            return values.createError({
                path: values.path,
                message: `Amount cannot be greater than ${parent?.maxPayment}`,
            });
        }
        return true;
    }),
    method: Yup.string()
        .required("Transaction Method is required")
        .typeError("Transaction Method is Required"),
});
const RepaymentModal = ({ onDismiss, onSuccess, loanId, }) => {
    const [loading, setLoading] = (0, react_1.useState)(true);
    const [detail, setDetail] = (0, react_1.useState)();
    const [loanDetail, setLoanDetail] = (0, react_1.useState)();
    const [isModalOpen, setIsModalOpen] = (0, react_1.useState)(false);
    const theme = (0, react_native_paper_1.useTheme)();
    const { info, axiosInstance } = (0, context_1.useLMS)();
    const { setAppError } = (0, hooks_1.useAppErrors)();
    const getALoanDetail = (0, react_1.useCallback)(async () => {
        try {
            const { data: repaymentDetail } = await axiosInstance.get(`/v1/external-lending/sme/loans/repayment-details?${query_string_1.default.stringify(info || {})}`);
            const { data } = await axiosInstance.get(`/v1/external-lending/sme/loans/${loanId}`);
            setDetail(repaymentDetail);
            setLoanDetail(data.loan);
        }
        catch (e) {
            setAppError(e.response.data);
        }
        finally {
            setLoading(false);
        }
    }, [info, axiosInstance, loanId, setAppError]);
    const initialValue = (0, react_1.useMemo)(() => {
        return {
            user_id: loanDetail?.user_id ?? "",
            amount: "0",
            type: typings_1.TransactionType.REPAYMENT,
            method: undefined,
            payment_date: moment_1.default.utc().format(),
            maxPayment: loanDetail?.pending?.principal || 0,
            transaction_image: "",
        };
    }, [loanDetail]);
    const onSubmit = (0, react_1.useCallback)(async (values, actions) => {
        try {
            actions.setSubmitting(true);
            await axiosInstance.post(`/v1/external-lending/sme/loans/${loanId}/transaction`, values);
            onSuccess?.();
            onDismiss?.();
            segment_1.default.track(segmentEvents_1.SEGMENT_EVENTS.SUCCESS_RECORD_REPAYMENT, {
                loan_id: loanId,
                repayment_amount: values.amount,
                transaction_method: values.method,
                payment_date: values.payment_date,
                file_attached: !!values.transaction_image,
            });
        }
        catch (e) {
            setAppError(e.response.data);
        }
        finally {
            actions.setSubmitting(false);
        }
    }, [axiosInstance, loanId, onDismiss, onSuccess, setAppError]);
    (0, react_1.useEffect)(() => {
        if (loanId) {
            getALoanDetail();
        }
        else {
            (0, react_native_flash_message_1.showMessage)({ message: "Invalid loan id", type: "danger" });
        }
    }, [getALoanDetail, loanId]);
    const Form = (0, react_1.useCallback)(() => {
        return (react_1.default.createElement(react_native_1.View, { style: styles.formContainer }, !loading && loanDetail && (react_1.default.createElement(formik_1.Formik, { initialValues: initialValue, onSubmit: onSubmit, validationSchema: validationSchema }, ({ values, handleSubmit, isSubmitting, isValid, setFieldValue, }) => (react_1.default.createElement(react_1.default.Fragment, null,
            react_1.default.createElement(react_native_1.View, { style: styles.header },
                react_1.default.createElement(react_native_1.Text, { style: styles.headerText }, "Record Payment"),
                react_1.default.createElement(react_native_1.TouchableOpacity, { onPress: () => {
                        setIsModalOpen(false);
                        onDismiss?.();
                    } },
                    react_1.default.createElement(AntDesign_1.default, { name: "close", size: 25 }))),
            react_1.default.createElement(react_native_1.View, { style: styles.spacing }),
            react_1.default.createElement(components_1.FieldTextInput, { title: "Amount", name: "amount", value: values.amount, keyboardType: "numeric", right: react_1.default.createElement(react_native_paper_1.TextInput.Affix, { text: "PKR" }) }),
            react_1.default.createElement(react_native_1.View, { style: styles.spacing }),
            react_1.default.createElement(react_native_1.Text, null, "Payment Date*"),
            react_1.default.createElement(FieldDatePicker_1.FieldDatePicker, { name: "payment_date" }),
            react_1.default.createElement(react_native_1.View, { style: styles.spacing }),
            react_1.default.createElement(components_1.FieldDropdownInput, { title: "Transaction Method", name: "method", items: data_1.TRANSACTION_METHOD, onValueChange: (value) => {
                    setFieldValue("method", value);
                } }),
            react_1.default.createElement(react_native_1.View, { style: styles.spacing }),
            react_1.default.createElement(components_1.SingleAttachment, { name: "transaction_image", title: "Transaction Image (Optional)" }),
            react_1.default.createElement(react_native_1.View, { style: styles.spacingLarge }),
            react_1.default.createElement(react_native_1.View, { style: styles.footer },
                react_1.default.createElement(react_native_paper_1.Button, { style: { width: "100%" }, mode: "contained", onPress: () => handleSubmit(), disabled: !isValid || isSubmitting }, "Save"))))))));
    }, [initialValue, loading, loanDetail, onDismiss, onSubmit]);
    const Information = () => {
        return (react_1.default.createElement(react_native_1.ScrollView, { style: styles.scrollView },
            react_1.default.createElement(react_native_1.View, { style: styles.header },
                react_1.default.createElement(react_native_1.Text, { style: styles.headerText }, "Make Repayment"),
                react_1.default.createElement(react_native_1.TouchableOpacity, { onPress: () => {
                        setIsModalOpen(false);
                        onDismiss?.();
                    } },
                    react_1.default.createElement(AntDesign_1.default, { name: "close", size: 25 }))),
            react_1.default.createElement(react_native_1.View, { style: styles.spacing }),
            detail?.repayment_address && (react_1.default.createElement(react_1.default.Fragment, null,
                react_1.default.createElement(react_native_1.View, { style: [styles.repaymentAddress] },
                    react_1.default.createElement(react_native_1.Text, { style: styles.placeholder }, "Bank Name"),
                    react_1.default.createElement(react_native_1.Text, { style: styles.repaymentText }, detail.repayment_address.bank_name),
                    react_1.default.createElement(react_native_1.View, { style: styles.spacingSmall }),
                    react_1.default.createElement(react_native_1.Text, { style: styles.placeholder }, "Account Title"),
                    react_1.default.createElement(react_native_1.Text, { style: styles.repaymentText }, detail.repayment_address.account_title),
                    react_1.default.createElement(react_native_1.View, { style: styles.spacingSmall }),
                    react_1.default.createElement(react_native_1.Text, { style: styles.placeholder }, "Account Number"),
                    react_1.default.createElement(react_native_1.View, { style: styles.row },
                        react_1.default.createElement(react_native_1.Text, { style: styles.repaymentText }, detail.repayment_address.account_number),
                        react_1.default.createElement(react_native_1.TouchableOpacity, { onPress: () => {
                                react_native_1.Clipboard.setString(detail.repayment_address.account_number);
                                (0, react_native_flash_message_1.showMessage)({
                                    message: "Account Number successfully copied",
                                    type: "success",
                                });
                            } },
                            react_1.default.createElement(AntDesign_1.default, { name: "copy1", style: styles.iconSpacing }))),
                    react_1.default.createElement(react_native_1.View, { style: styles.spacingSmall }),
                    react_1.default.createElement(react_native_1.Text, { style: styles.placeholder }, "IBAN"),
                    react_1.default.createElement(react_native_1.View, { style: styles.row },
                        react_1.default.createElement(react_native_1.Text, { style: styles.repaymentText }, detail.repayment_address.iban),
                        react_1.default.createElement(react_native_1.TouchableOpacity, { onPress: () => {
                                react_native_1.Clipboard.setString(detail.repayment_address.iban);
                                (0, react_native_flash_message_1.showMessage)({
                                    message: "IBAN successfully copied",
                                    type: "success",
                                });
                            } },
                            react_1.default.createElement(AntDesign_1.default, { name: "copy1", style: styles.iconSpacing })))),
                react_1.default.createElement(react_native_1.View, { style: styles.spacing }))),
            react_1.default.createElement(react_native_1.View, { style: styles.instructions },
                react_1.default.createElement(react_native_1.View, { style: styles.instructionsHeader },
                    react_1.default.createElement(AntDesign_1.default, { name: "infocirlce" }),
                    react_1.default.createElement(react_native_1.View, { style: styles.iconSpacing }),
                    react_1.default.createElement(react_native_1.Text, { style: [styles.repaymentText, { color: "rgb(124, 117, 126)" }] }, "Repayment Instructions")),
                react_1.default.createElement(react_native_1.View, { style: styles.spacing }),
                react_1.default.createElement(react_native_1.Text, null, "A step by step guide on how to repay your financing amount."),
                react_1.default.createElement(react_native_1.View, { style: styles.spacing }),
                react_1.default.createElement(react_native_1.Text, null, detail?.instructions)),
            react_1.default.createElement(react_native_1.View, { style: styles.spacing }),
            react_1.default.createElement(react_native_paper_1.Button, { mode: "outlined", style: { width: "100%" }, onPress: () => {
                    segment_1.default.track(segmentEvents_1.SEGMENT_EVENTS.CLICK_RECORD_REPAYMENT, {
                        loan_id: loanId,
                    });
                    setIsModalOpen(true);
                } }, "Record Repayment")));
    };
    return (react_1.default.createElement(react_1.default.Fragment, null,
        react_1.default.createElement(react_native_1.View, { style: [
                styles.modalContainer,
                { backgroundColor: theme.colors.background },
            ] },
            isModalOpen && react_1.default.createElement(Form, null),
            !isModalOpen && react_1.default.createElement(Information, null))));
};
exports.RepaymentModal = RepaymentModal;
const styles = react_native_1.StyleSheet.create({
    formContainer: {
        width: "100%",
    },
    header: {
        flexDirection: "row",
        justifyContent: "space-between",
        width: "100%",
    },
    headerText: {
        fontWeight: "600",
        fontSize: 16,
    },
    spacing: {
        marginVertical: 8,
    },
    textInput: {
        width: "100%",
    },
    spacingLarge: {
        marginVertical: 16,
    },
    footer: {
        flexDirection: "row",
        justifyContent: "space-between",
        width: "100%",
    },
    scrollView: {
        width: "100%",
    },
    repaymentAddress: {
        padding: 10,
        borderWidth: 1,
        borderRadius: 5,
        borderColor: "#F7F7F7",
        backgroundColor: "#F7F7F7",
    },
    repaymentText: {
        fontWeight: "500",
    },
    spacingSmall: {
        marginVertical: 7,
    },
    placeholder: {
        color: "rgb(124, 117, 126)",
    },
    row: {
        flexDirection: "row",
        alignItems: "center",
    },
    iconSpacing: {
        marginLeft: 8,
    },
    instructions: {
        padding: 10,
        borderWidth: 1,
        borderRadius: 5,
        borderColor: "#F7F7F7",
    },
    instructionsHeader: {
        flexDirection: "row",
        justifyContent: "flex-start",
        alignItems: "center",
    },
    modalContainer: {
        alignItems: "flex-end",
        padding: 16,
        borderRadius: 10,
        minWidth: 300,
        maxWidth: 500,
        maxHeight: "90%",
        width: "100%",
    },
});
