"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ApprovedLoan = void 0;
const react_1 = __importDefault(require("react"));
const react_native_1 = require("react-native");
const react_native_paper_1 = require("react-native-paper");
const loan_1 = require("../../typings/loan");
const segment_1 = __importDefault(require("../../utils/segment"));
const segmentEvents_1 = require("../../data/segmentEvents");
const color_1 = require("../../data/color");
const helpers_1 = require("../../helpers");
const react_native_tab_view_1 = require("react-native-tab-view");
const components_1 = require("../../components");
const LoanItemDetails_1 = require("../components/LoanItemDetails");
const RepaymentsDetails_1 = require("../components/RepaymentsDetails");
const ApprovedLoan = ({ loanDetail, index = 0, onRecordClick, setValue, }) => {
    const theme = (0, react_native_paper_1.useTheme)();
    const layout = (0, react_native_1.useWindowDimensions)();
    const isVisible = loanDetail.status !== loan_1.FinanceAppState.IN_PROGRESS &&
        loanDetail.status !== loan_1.FinanceAppState.UNDER_REVIEW &&
        loanDetail.status !== loan_1.FinanceAppState.APPROVED &&
        loanDetail.status !== loan_1.FinanceAppState.READY_TO_DISBURSE;
    const routes = [
        { key: "Details", title: "Details" },
        { key: "Repayments", title: "Repayments" },
    ];
    const renderScene = (0, react_native_tab_view_1.SceneMap)({
        Details: () => (react_1.default.createElement(react_native_1.ScrollView, { style: styles.tabContent },
            react_1.default.createElement(LoanItemDetails_1.LoanItemDetails, { ...loanDetail }))),
        Repayments: () => (react_1.default.createElement(react_native_1.ScrollView, { style: styles.tabContent },
            react_1.default.createElement(RepaymentsDetails_1.LoanRepayment, { ...loanDetail }))),
    });
    return (react_1.default.createElement(react_1.default.Fragment, null,
        react_1.default.createElement(react_native_1.View, { style: styles.column },
            react_1.default.createElement(react_native_1.View, { style: styles.row },
                react_1.default.createElement(react_native_paper_1.Text, { style: styles.title },
                    "Loan ",
                    loanDetail.display_id),
                react_1.default.createElement(react_native_paper_1.Chip, { mode: "outlined", style: styles.chip, textStyle: { color: color_1.LOAN_COLOR[loanDetail.status] } }, (0, helpers_1.pascalCase)(loanDetail.status.replaceAll("_", " ")))),
            isVisible && (react_1.default.createElement(react_1.default.Fragment, null,
                react_1.default.createElement(react_native_paper_1.Card, { style: styles.innerCard, elevation: 0 },
                    react_1.default.createElement(react_native_1.View, { style: styles.innerRow },
                        react_1.default.createElement(react_native_1.View, { style: styles.row },
                            react_1.default.createElement(react_native_paper_1.Text, { style: styles.headerText }, "Payable Today:"),
                            react_1.default.createElement(react_native_paper_1.Text, { style: styles.headerText },
                                "PKR",
                                " ",
                                (parseFloat(`${loanDetail.pending?.principal}` || "0") +
                                    parseFloat(`${loanDetail.pending?.markup_fee}` || "0") +
                                    parseFloat(`${loanDetail.pending?.late_fees}` || "0")).toFixed(2))),
                        react_1.default.createElement(components_1.Gutter, { spacing: 0.5 }),
                        react_1.default.createElement(react_native_1.View, { style: styles.row },
                            react_1.default.createElement(react_native_paper_1.Text, { style: styles.captionText }, "Total Principal:"),
                            react_1.default.createElement(react_native_paper_1.Text, { style: styles.captionText },
                                "PKR",
                                " ",
                                parseFloat(`${loanDetail.required_financing}` || "0").toFixed(2))),
                        react_1.default.createElement(components_1.Gutter, { spacing: 0.5 }),
                        react_1.default.createElement(react_native_1.View, { style: styles.row },
                            react_1.default.createElement(react_native_paper_1.Text, { style: styles.captionText }, "Markup Accrued:"),
                            react_1.default.createElement(react_native_paper_1.Text, { style: styles.captionText },
                                "PKR ",
                                parseFloat(`${loanDetail.markup}` || "0").toFixed(2))),
                        react_1.default.createElement(components_1.Gutter, { spacing: 0.5 }),
                        loanDetail.status === "disbursed" && (react_1.default.createElement(react_native_paper_1.Button, { mode: "contained", style: styles.button, onPress: () => {
                                segment_1.default.track(segmentEvents_1.SEGMENT_EVENTS.CLICK_MAKE_REPAYMENT, {
                                    loan_id: loanDetail._id,
                                });
                                onRecordClick?.();
                            } }, "Make Payment")))))),
            react_1.default.createElement(components_1.Gutter, { spacing: 1 })),
        react_1.default.createElement(react_native_tab_view_1.TabView, { navigationState: { index, routes }, renderScene: renderScene, onIndexChange: setValue, initialLayout: { width: layout.width }, renderTabBar: (props) => (react_1.default.createElement(react_native_tab_view_1.TabBar, { ...props, indicatorStyle: { backgroundColor: theme.colors.primary }, style: { backgroundColor: theme.colors.background }, labelStyle: {
                    color: "#000",
                } })) })));
};
exports.ApprovedLoan = ApprovedLoan;
const styles = react_native_1.StyleSheet.create({
    column: {
        flexDirection: "column",
    },
    row: {
        flexDirection: "row",
        justifyContent: "space-between",
        alignItems: "center",
    },
    title: {
        fontWeight: "600",
        fontSize: 18,
    },
    chip: {
        borderWidth: 1,
        borderRadius: 40,
    },
    innerCard: {
        width: "100%",
        marginTop: 16,
        padding: 16,
        borderWidth: 1,
    },
    innerRow: {
        flexDirection: "column",
        justifyContent: "space-between",
    },
    headerText: {
        fontWeight: "500",
        fontSize: 16,
    },
    tabContent: {
        flex: 1,
    },
    captionText: {
        fontSize: 14,
        color: "gray",
    },
    button: {
        borderRadius: 4,
        marginTop: 16,
    },
    tabsContainer: {
        width: "100%",
        marginTop: 16,
    },
    tabs: {
        backgroundColor: "white",
    },
});
