import React from 'react';
import {Text} from 'react-native-paper';
import {Linking, TouchableOpacity, View, ViewStyle} from 'react-native';
import {useLMS} from '../context/context';
import {Gutter} from '../component/Gutter';
import FontAwesome from 'react-native-vector-icons/FontAwesome';
import {showMessage} from 'react-native-flash-message';

export const RequestEdit = () => {
  const {userDetail} = useLMS();

  const openWhatsApp = () => {
    let url =
      'whatsapp://send?text=' +
      encodeURIComponent('Hai I need help') +
      '&phone=' +
      '+923180110801';

    Linking.canOpenURL(url)
      .then(supported => {
        if (supported) {
          return Linking.openURL(url);
        } else {
          showMessage({
            message: 'Please install WhatsApp to send a direct message.',
            type: 'danger',
          });
        }
      })
      .catch(err =>
        showMessage({
          message: err,
          type: 'danger',
        }),
      );
  };

  return (
    <View style={styles.wrapper}>
      <Text variant={'bodyLarge'}>Want to make changes to your profile?</Text>
      <Gutter spacing={0.2} />
      <Text variant={'bodySmall'}>
        Request changes to be made to your profile using the following method:
      </Text>
      <View style={{}} />
      <Gutter gap={1} />
      <TouchableOpacity
        onPress={() => {
          openWhatsApp();
        }}>
        <View style={{...styles.row, alignItems: 'center'}}>
          <FontAwesome name={'whatsapp'} color={'#075E54'} size={20} />
          <Gutter gap={0.4} />
          <Text variant={'bodyMedium'}>{'+92-3180110801'}</Text>
        </View>
      </TouchableOpacity>
    </View>
  );
};

const styles = {
  wrapper: {
    display: 'flex',
    flexDirection: 'column',
    padding: 16,
    width: '100%',
    flexWrap: 'nowrap',
  } as ViewStyle,

  row: {
    display: 'flex',
    flexDirection: 'row',
  } as ViewStyle,

  column: {
    display: 'flex',
    flexDirection: 'column',
  } as ViewStyle,

  gap: {
    width: 10,
    height: 10,
  },
};
