// DropdownInput

import * as React from "react";
import { useCallback } from "react";
import { HelperText, Text } from "react-native-paper";
import RNPickerSelect, { PickerSelectProps } from "react-native-picker-select";
import { useField } from "formik";

export type FieldDropdownInputProps = Omit<
  PickerSelectProps,
  "onFocus" | "label"
> & {
  name: string;
  placeholder?: string;
  title?: string;
};

export const FieldDropdownInput: React.FC<FieldDropdownInputProps> = ({
  onValueChange,
  name,
  title,
  ...props
}) => {
  const [, meta, helpers] = useField(name as any);

  const error = meta.touched && meta.error;

  const handleBlur = useCallback(() => {
    helpers.setValue(meta.value && meta.value?.trim());
    helpers.setTouched(true);
  }, [helpers, meta.value]);

  return (
    <React.Fragment>
      {title && <Text variant="labelSmall">{title}</Text>}
      <RNPickerSelect
        onOpen={() => helpers.setTouched(true)}
        onValueChange={(value, index) => {
          console.log(value, "lasdfk");
          handleBlur();
          onValueChange(value, index);
        }}
        style={{
          inputAndroid: {
            ...pickerSelectStyles.inputAndroid,
            borderColor: error ? "rgb(105, 0, 5)" : "gray",
          },
          inputIOS: {
            ...pickerSelectStyles.inputIOS,
            borderColor: error ? "rgb(105, 0, 5)" : "gray",
          },
        }}
        {...props}
      />
      <HelperText type="error" visible={!!error}>
        {error}
      </HelperText>
    </React.Fragment>
  );
};

const pickerSelectStyles = {
  inputIOS: {
    fontSize: 16,
    paddingVertical: 16,
    paddingHorizontal: 10,
    borderWidth: 1,
    borderColor: "gray",
    borderRadius: 4,
    color: "black",
    paddingRight: 30,
    backgroundColor: "white",
  },
  inputAndroid: {
    fontSize: 16,
    paddingVertical: 12,
    paddingHorizontal: 10,
    borderWidth: 0.5,
    borderColor: "gray",
    borderRadius: 8,
    color: "black",
    paddingRight: 30,
    backgroundColor: "white",
  },
};
