import React, {type CSSProperties, useCallback} from 'react';
import {useField} from 'formik';
import {
  HelperText,
  Text,
  TextInput,
  TextInputProps,
  useTheme,
} from 'react-native-paper';
import {POSITIVE_NUMBER_WITH_DECIMAL, Regex} from '../../helpers';

export type FieldNumberInputProps = Omit<
  TextInputProps,
  'onBlur' | 'onChange' | 'onFocus'
> & {
  regex?: Regex;
  name: string;
  title?: string;
  placeholder?: string;
  wrapperStyle?: CSSProperties;
  nextInputRef?: React.MutableRefObject<typeof TextInput> | null;
  onBlur?(text?: string): void;
};

export const FieldNumberInput = React.forwardRef<
  TextInputProps,
  FieldNumberInputProps
>(
  (
    {name, regex, onBlur, title, id, wrapperStyle, nextInputRef, ...props},
    ref,
  ) => {
    const theme = useTheme();
    const [field, meta, helpers] = useField(name as any);

    const error = meta.touched && meta.error;

    const handleBlur = useCallback(() => {
      helpers.setTouched(true);
      onBlur?.(meta.value);
    }, [helpers, meta.value, onBlur]);

    const onChange = (text: string) => {
      if (text.match(regex || POSITIVE_NUMBER_WITH_DECIMAL)) {
        helpers.setValue(text);
      }
    };

    return (
      <React.Fragment>
        {title && <Text variant="labelSmall">{title}</Text>}
        <TextInput
          mode={'outlined'}
          id={id || 'outlined-basic'}
          value={field.value ? field.value.toString() : ''}
          onChangeText={text => {
            onChange?.(text);
          }}
          error={!!error}
          onBlur={handleBlur}
          style={{backgroundColor: theme.colors.background}}
          {...props}
        />
        <HelperText type="error" visible={!!error}>
          {error}
        </HelperText>
      </React.Fragment>
    );
  },
);

FieldNumberInput.displayName = 'FieldNumberInput';
