import * as React from 'react';
import {useCallback} from 'react';
import {
  HelperText,
  Text,
  TextInput,
  type TextInputProps,
} from 'react-native-paper';
import {useField} from 'formik';

export type FieldTextInputProps = Omit<
  TextInputProps,
  'onFocus' | 'onChange' | 'label'
> & {
  name: string;
  placeholder?: string;
  title?: string;
  onChange?(text: string): void;
};

export const FieldTextInput: React.FC<FieldTextInputProps> = ({
  name,
  onChange,
  title,
  onBlur,
  ...props
}) => {
  const [field, meta, helpers] = useField(name);

  const error = meta.touched && meta.error;

  const handleBlur = useCallback(() => {
    helpers.setValue(meta.value && meta.value?.trim());
    helpers.setTouched(true);
    onBlur?.(meta.value);
  }, [helpers, meta.value, onBlur]);

  return (
    <React.Fragment>
      {title && <Text variant="labelSmall">{title}</Text>}
      <TextInput
        mode={'outlined'}
        error={!!error}
        id={name}
        value={field.value ? field.value.toString() : ''}
        onChangeText={text => {
          helpers.setValue(text);
          onChange?.(text);
        }}
        style={{width: '100%'}}
        onBlur={handleBlur}
        {...props}
      />
      <HelperText type="error" visible={!!error}>
        {error}
      </HelperText>
    </React.Fragment>
  );
};
