import type {IFile} from '../typings';

export type AttachementType = {
  isAttachment: boolean;
  values: IFile[];
  required: boolean;
  title: string;
};

export const CBFS_INITIAL_DATA = {
  contactNumber: '',
  businessRole: '',
  business: '',
  fullName: '',
  email: '',
  businessName: '',
  businessType: 'partnership',
  businessAddress: '',
  ntn: '',
  partnerCnic: {
    isAttachment: true,
    values: [],
    required: true,
    title: 'Partner CNIC',
  },
  partnershipDeed: {
    isAttachment: true,
    values: [],
    required: true,
    title: 'Partnership Deed',
  },
  incorporationCertificate: {
    isAttachment: true,
    values: [],
    required: false,
    title: 'Incorporation Certificate',
  },
  authorityLetter: {
    isAttachment: true,
    values: [],
    required: true,
    title: 'Authority Letter',
  },
  bankDetails: {
    bankCode: '',
    accountTitle: '',
    accountNumber: '',
    iban: '',
  },
};

export const BusinessType = {
  partnership: {
    partnerCnic: {
      isAttachment: true,
      values: [],
      required: true,
      title: 'Partner CNIC',
    },
    partnershipDeed: {
      isAttachment: true,
      values: [],
      required: true,
      title: 'Partnership Deed',
    },
    incorporationCertificate: {
      isAttachment: true,
      values: [],
      required: false,
      title: 'Incorporation Certificate',
    },
    authorityLetter: {
      isAttachment: true,
      values: [],
      required: true,
      title: 'Authority Letter',
    },
  },
  individual: {
    cnicFront: {
      isAttachment: true,
      values: [],
      required: true,
      title: 'CNIC Front',
    },
    cnicBack: {
      isAttachment: true,
      values: [],
      required: true,
      title: 'CNIC Back',
    },
  },
  branchOffice: {
    permissionLetter: {
      isAttachment: true,
      values: [],
      required: true,
      title: 'Permission Letter',
    },
    signatoryPassports: {
      isAttachment: true,
      values: [],
      required: true,
      title: 'Signatory Passports',
    },
    formIIParticulars: {
      isAttachment: true,
      values: [],
      required: true,
      title: 'Form IIParticulars',
    },
    principalOfficeAuthorization: {
      isAttachment: true,
      values: [],
      required: true,
      title: 'Principal Office Authorization',
    },
  },
  company: {
    formAB: {
      isAttachment: true,
      values: [],
      required: true,
      title: 'Form AB',
    },
    addendum: {
      isAttachment: true,
      values: [],
      required: true,
      title: 'Addendum',
    },
    directorsResolution: {
      isAttachment: true,
      values: [],
      required: true,
      title: 'Directors Resolution',
    },
    memorandumArticlesAssociation: {
      isAttachment: true,
      values: [],
      required: true,
      title: 'Memorandum Articles Association',
    },
    boardMemberCnic: {
      isAttachment: true,
      values: [],
      required: true,
      title: 'Board Member CNIC',
    },
    pocCnic: {
      isAttachment: true,
      values: [],
      required: true,
      title: 'POC CNIC',
    },
    beneficialOwnerCnic: {
      isAttachment: true,
      values: [],
      required: true,
      title: 'Beneficial Owner CNIC',
    },
  },
  soleProprietorship: {
    cnicFront: {
      isAttachment: true,
      values: [],
      required: true,
      title: 'CNIC Front',
    },
    cnicBack: {
      isAttachment: true,
      values: [],
      required: true,
      title: 'CNIC Back',
    },
    proprietorshipDeclaration: {
      isAttachment: true,
      values: [],
      required: true,
      title: 'Proprietorship Declaration',
    },
    ntnCertificate: {
      isAttachment: true,
      values: [],
      required: true,
      title: 'NTN Certificate',
    },
    bankStatement: {
      isAttachment: true,
      values: [],
      required: false,
      title: 'Bank Statement',
    },
  },
};

export const BUSINESS_TYPE = [
  {
    label: 'Individual',
    value: 'individual',
  },
  {
    label: 'Branch Office',
    value: 'branchOffice',
  },
  {
    label: 'Partnership',
    value: 'partnership',
  },
  {
    label: 'Company',
    value: 'company',
  },
  {
    label: 'Sole Proprietorship',
    value: 'soleProprietorship',
  },
];

export const TRANSACTION_METHOD = [
  {value: 'bank_transfer', label: 'Bank Transfer'},
  {value: 'cash_via_fso', label: 'Cash Via Fso'},
  {value: 'one_bill', label: 'One Bill'},
  {value: 'online_cash_deposit', label: 'Online Cash Deposit'},
  {value: 'clearing_cheque_deposit', label: 'Clearing Cheque Deposit'},
];

export const CREATE_LOAN = {
  invoice_data: [],
  required_financing: 0,
  tenure: 0,
};

export type PREDICTION = {
  amountPending: number;
  amountRepaid: number;
  lateFeesPending: number;
  lateFeesRepaid: number;
  markupPending: number;
  markupRepaid: number;
  statementTransactions: any[];
};
