import React, {useCallback, useEffect, useState} from 'react';
import {Text, View} from 'react-native';
import {ActivityIndicator} from 'react-native-paper';
import {useLMS} from '../context/context';
import {useAppErrors} from '../hooks';
import {FinanceAppState, ILoan} from '../typings/loan';
import {ApprovedLoan} from '../screen/components/ApprovedLoanDetails';
import {RejectedLoan} from '../screen/components/RejectedLoan';

type LoanDetailsProps = {
  loanId: string;
  onRecordClick?(): void;
  isRepayment?: boolean;
};

export const LoanDetails: React.ComponentType<LoanDetailsProps> = ({
  loanId,
  onRecordClick,
  isRepayment,
}) => {
  const [value, setValue] = useState(isRepayment ? 1 : 0);
  const [loanDetail, setLoanDetail] = useState<ILoan>();
  const {axiosInstance} = useLMS();

  const {setAppError} = useAppErrors();

  const getALoanDetail = useCallback(async () => {
    try {
      const {data} = await axiosInstance.get(
        `/v1/external-lending/sme/loans/${loanId}`,
      );

      setLoanDetail(data?.loan);
    } catch (e: any) {
      setAppError(e.response.data);
    }
  }, [axiosInstance, loanId, setAppError]);

  useEffect(() => {
    if (loanId) {
      getALoanDetail();
    }
  }, [getALoanDetail, loanId]);

  return (
    <View style={{padding: 16, height: '100%'}}>
      {!loanId && <Text>Provide Valid LoanId</Text>}
      {loanDetail ? (
        loanDetail?.status !== FinanceAppState.REJECTED ? (
          <ApprovedLoan
            loanDetail={loanDetail}
            index={value}
            setValue={setValue}
            onRecordClick={onRecordClick}
          />
        ) : (
          <RejectedLoan loanDetail={loanDetail} value={value} />
        )
      ) : (
        <ActivityIndicator size="large" />
      )}
    </View>
  );
};
