import { StyleSheet, View } from "react-native";
import { useLMS } from "../context/context";
import { Card, Text } from "react-native-paper";
import {
  convertToTitleCase,
  deleteKeysFromObject,
  filterArrays,
  formatFileSize,
  getArrayKeysNotIFileType,
  pascalCase,
} from "../helpers";
import { IKyb } from "../typings/kyb";
import { Gutter } from "../components";
import React from "react";
import { FileDto } from "../typings/file";
import AntDesign from "react-native-vector-icons/AntDesign";
import MaterialCommunityIcons from "react-native-vector-icons/MaterialCommunityIcons";

export const Profile = () => {
  const { userDetail } = useLMS();
  const arr = deleteKeysFromObject(
    filterArrays(userDetail?.kyb),
    getArrayKeysNotIFileType(userDetail?.kyb || ({} as IKyb)),
  );
  return (
    <View>
      {userDetail?.kyb && (
        <View>
          <Text variant={"titleLarge"} style={{ fontWeight: "500" }}>
            Personal Details
          </Text>
          <Gutter spacing={0.8} />
          <Text variant={"bodySmall"} style={styles.label}>
            {"Full Name"}{" "}
          </Text>
          <Text variant={"bodyLarge"}>{userDetail.kyb.fullName}</Text>
          <Gutter spacing={0.5} />

          <Text variant={"bodySmall"} style={styles.label}>
            {"Contact Number"}{" "}
          </Text>
          <Text variant={"bodyLarge"}>{userDetail.kyb.contactNumber}</Text>
          <Gutter spacing={0.5} />

          <Text variant={"bodySmall"} style={styles.label}>
            {"Email"}
          </Text>
          <Text variant={"bodyLarge"}>{userDetail.kyb.email}</Text>
          <Gutter spacing={1.5} />

          <Text variant={"titleLarge"} style={{ fontWeight: "500" }}>
            Business Details
          </Text>
          <Gutter spacing={0.8} />
          <Text variant={"bodySmall"} style={styles.label}>
            {"Business Type"}{" "}
          </Text>
          <Text variant={"bodyLarge"}>{pascalCase(userDetail.kyb.status)}</Text>
          <Gutter spacing={0.5} />

          <Text variant={"bodySmall"} style={styles.label}>
            {"NTN"}
          </Text>
          <Text variant={"bodyLarge"}>{userDetail.kyb.ntn}</Text>
          <Gutter spacing={0.5} />

          <Text variant={"bodySmall"} style={styles.label}>
            {"Business Address"}
          </Text>
          <Text variant={"bodyLarge"}>{userDetail.kyb.businessAddress}</Text>
          <Gutter spacing={0.5} />

          <Gutter spacing={1.5} />

          <Text variant={"titleLarge"} style={{ fontWeight: "500" }}>
            Additional Details
          </Text>
          <Gutter spacing={0.8} />

          {Object.entries(arr).map(([key, value]) => {
            const attachment = value as FileDto[];
            return (
              <>
                <Text variant={"labelLarge"} style={{ fontWeight: "500" }}>
                  {convertToTitleCase(key)}
                </Text>
                <Gutter spacing={0.1} />
                {attachment.map((m: any) => (
                  <Card key={m.resourceURL} style={styles.card} elevation={0}>
                    <View style={styles.cardContent}>
                      <View style={styles.attachmentWrapper}>
                        <Text>{m.name}</Text>
                        <Text style={styles.caption}>
                          {formatFileSize(m.size)} Completed
                        </Text>
                      </View>
                      <View style={styles.iconRow}>
                        <MaterialCommunityIcons
                          name={"delete"}
                          color={"rgba(0, 0, 0, 0.56)"}
                          size={22}
                        />

                        <AntDesign
                          name={"checkcircle"}
                          color={"#178D46"}
                          size={22}
                        />
                      </View>
                    </View>
                  </Card>
                ))}
                <Gutter spacing={1} />
              </>
            );
          })}
        </View>
      )}
    </View>
  );
};

const styles = StyleSheet.create({
  label: { color: "rgb(124, 117, 126)" },
  row: { flexDirection: "row" },
  iconRow: {
    flex: 1,
    flexDirection: "row",
    alignItems: "center",
  },
  errorText: {
    color: "red",
    marginTop: 10,
  },
  uploadButton: {
    borderRadius: 6,
  },
  card: {
    width: "100%",
    padding: 10,
    justifyContent: "center",
    backgroundColor: "transparent",
    borderRadius: 4,
    borderWidth: 1,
    borderColor: "#DBDBDB",
    marginTop: 10,
  },
  cardContent: {
    flexDirection: "row",
    justifyContent: "space-between",
    alignItems: "center",
    flexWrap: "nowrap",
  },
  caption: {
    color: "gray",
  },
  attachmentWrapper: {
    width: "100%",
    maxWidth: "80%",
  },
});
