import * as React from 'react';
import {useCallback} from 'react';
import {StyleSheet, TouchableOpacity, View} from 'react-native';
import {Chip, Text} from 'react-native-paper';
import {ILoan, LoanListType} from '../../typings/loan';
import {pascalCase} from '../../helpers';
import {LOAN_COLOR} from '../../data/color';

const styles = StyleSheet.create({
  container: {
    flexDirection: 'column',
  },
  loanContainer: {
    marginBottom: 16,
    padding: 16,
    backgroundColor: 'white',
    borderRadius: 8,
    elevation: 3,
    borderWidth: 1,
    borderColor: '#E0E0E0',
  },
  flexRow: {
    flexDirection: 'row',
    justifyContent: 'space-between',
    alignItems: 'center',
    marginBottom: 8,
  },
  chip: {
    borderWidth: 1,
    borderRadius: 40,
    backgroundColor: '#fff',
  },
});

type LoansTableProps = {
  dataSource: ILoan[];
  onPress?(type: LoanListType.application, loan: ILoan): void;
};

export const ApplicationTable: React.FC<LoansTableProps> = ({
  dataSource = [],
  onPress,
}) => {
  const Render = useCallback(
    ({...row}: ILoan) => {
      return (
        <TouchableOpacity
          onPress={() => onPress?.(LoanListType.application, {...row})}>
          <View key={row.display_id} style={styles.loanContainer}>
            <View style={styles.flexRow}>
              <Text>Loan:</Text>
              <Text>{row.display_id}</Text>
            </View>
            <View style={styles.flexRow}>
              <Text>Status:</Text>
              <Chip
                mode="outlined"
                style={[
                  styles.chip,
                  {
                    borderColor: LOAN_COLOR[row.status],
                  },
                ]}>
                <Text style={{color: LOAN_COLOR[row.status]}}>
                  {pascalCase(row.status.replaceAll('_', ' '))}
                </Text>
              </Chip>
            </View>
            <View style={styles.flexRow}>
              <Text>Amount:</Text>
              <Text>{(row.required_financing || 0)?.toLocaleString()}</Text>
            </View>
          </View>
        </TouchableOpacity>
      );
    },
    [onPress],
  );

  return (
    <>
      {dataSource.map(row => (
        <Render key={row.display_id} {...row} />
      ))}
    </>
  );
};
