import React from 'react';
import {StyleSheet, View} from 'react-native';
import {Text} from 'react-native-paper';
import moment from 'moment';
import {FinanceAppState, ILoan} from '../../typings/loan';

export const LoanItemDetails: React.FC<ILoan> = ({...props}) => {
  const isVisible =
    props.status !== FinanceAppState.IN_PROGRESS &&
    props.status !== FinanceAppState.UNDER_REVIEW;

  return (
    <View style={styles.container}>
      <View style={styles.row}>
        <Text style={styles.label}>Total Loan Amount:</Text>
        <Text style={styles.value}>
          PKR {props.required_financing?.toLocaleString()}
        </Text>
      </View>

      <View style={styles.row}>
        <Text style={styles.label}>Tenure:</Text>
        <Text style={styles.value}>{props.tenure} days</Text>
      </View>

      <View style={styles.row}>
        <Text style={styles.label}>Markup Type:</Text>
        <Text style={styles.value}>{props.type}</Text>
      </View>

      {isVisible && (
        <>
          <View style={styles.row}>
            <Text style={styles.label}>Markup Rate:</Text>
            <Text style={styles.value}>
              {parseFloat(`${props.markup}`).toFixed(2)}
            </Text>
          </View>
          <View style={styles.row}>
            <Text style={styles.label}>Start Date:</Text>
            <Text style={styles.value}>
              {moment(props.disbursement_date).format('DD/MM/YY')}
            </Text>
          </View>
          <View style={styles.row}>
            <Text style={styles.label}>Repayment End Date:</Text>
            <Text style={styles.value}>
              {props.tenure
                ? moment(props.disbursement_date)
                    .add(props.tenure, 'days')
                    .format('DD/MM/YY')
                : '-'}
            </Text>
          </View>
        </>
      )}
    </View>
  );
};

const styles = StyleSheet.create({
  container: {
    display: 'flex',
    flexDirection: 'column',
    paddingTop: 20,
    paddingBottom: 20,
  },
  row: {
    display: 'flex',
    flexDirection: 'row',
    justifyContent: 'space-between',
    marginBottom: 5,
  },
  label: {
    fontWeight: '600',
    fontSize: 16,
  },
  value: {
    fontSize: 16,
  },
});
