import React from 'react';
import {Chip, Divider, Text, useTheme} from 'react-native-paper';
import {StyleSheet, View} from 'react-native';
import {FinanceAppState, ILoan} from '../../typings/loan';
import {pascalCase} from '../../helpers';
import AntDesign from 'react-native-vector-icons/AntDesign';
import {RejectedLoanDetails} from '../../screen/components/RejectedLoanDetails';
import {Gutter} from '../../components';

type ApprovedLoanProps = {
  loanDetail: ILoan;
  value: number;
};

export const RejectedLoan: React.FC<ApprovedLoanProps> = ({loanDetail}) => {
  const reason = loanDetail.statuses?.filter(
    d => d.status === FinanceAppState.REJECTED,
  );

  const theme = useTheme();

  return (
    <View style={{width: '100%'}}>
      <View>
        <View style={styles.row}>
          <Text style={{fontWeight: '600', fontSize: 18}}>
            Loan {loanDetail.display_id}
          </Text>
          <Chip
            mode="outlined"
            style={{marginLeft: 8}}
            textStyle={{color: theme.colors.error}}>
            {pascalCase(loanDetail.status.replaceAll('_', ' '))}
          </Chip>
        </View>
        <Divider style={{marginVertical: 8}} />
        <View style={styles.card}>
          <View style={[styles.row, {justifyContent: 'flex-start'}]}>
            <AntDesign name={'infocirlce'} />
            <Text
              style={{
                marginLeft: 8,
                fontWeight: '600',
                fontSize: 16,
              }}>
              Rejection Reason
            </Text>
          </View>
          <Text style={{fontSize: 14, marginTop: 8}}>
            {reason && reason.length > 0
              ? reason[reason.length - 1].comment
              : ''}
          </Text>
        </View>
      </View>
      <Gutter spacing={2} />
      <View style={{width: '100%'}}>
        <RejectedLoanDetails {...loanDetail} reason={reason} />
      </View>
    </View>
  );
};

const styles = StyleSheet.create({
  row: {
    flexDirection: 'row',
    alignItems: 'center',
    justifyContent: 'space-between',
  },
  card: {
    width: '100%',
    padding: 10,
  },
  tabBar: {
    backgroundColor: 'white',
  },
  tabLabel: {
    color: 'black',
  },
  tabIndicator: {
    backgroundColor: 'black',
  },
});
