import * as React from 'react';
import {useCallback} from 'react';
import {
  Linking,
  ScrollView,
  StyleSheet,
  TouchableOpacity,
  View,
} from 'react-native';
import {Chip, Text} from 'react-native-paper';
import moment from 'moment';
import {ILoanTransaction} from '../../typings/loan';
import {pascalCase} from '../../helpers';
import {LOAN_COLOR} from '../../data/color';

export const RepaymentTable: React.FC<{dataSource: ILoanTransaction[]}> = ({
  dataSource = [],
}) => {
  const RepaymentCard: React.FC<{
    transaction: ILoanTransaction;
    index: number;
  }> = useCallback(({transaction, index}) => {
    return (
      <View style={styles.card}>
        <View>
          <View style={styles.row}>
            <Text style={styles.text}>S.No: </Text>
            <Text style={styles.text}>{index + 1}</Text>
          </View>
          <View style={styles.row}>
            <Text style={styles.text}>Amount (PKR):</Text>
            <Text style={styles.text}>{transaction.amount}</Text>
          </View>
          <View style={styles.row}>
            <Text style={styles.text}>Method</Text>
            <Text style={styles.text}>
              {pascalCase(transaction?.method).replaceAll('_', ' ')}
            </Text>
          </View>
        </View>
        <View>
          <View style={styles.row}>
            <Text style={styles.text}>Payment Date</Text>
            <Text style={styles.text}>
              {moment(transaction.created_at).format('DD/MM/YY')}
            </Text>
          </View>
          <View style={styles.row}>
            <Text style={styles.text}>Status</Text>
            <Chip
              style={styles.chip}
              mode="outlined"
              textStyle={{color: LOAN_COLOR[transaction.status]}}>
              {pascalCase(transaction.status)}
            </Chip>
          </View>
        </View>
        <TouchableOpacity
          onPress={() => Linking.openURL(transaction.transaction_image)}>
          <Text style={styles.link}>Attachment-{index + 1}</Text>
        </TouchableOpacity>
      </View>
    );
  }, []);

  return (
    <ScrollView>
      {dataSource.map((transaction, index) => (
        <RepaymentCard
          key={transaction._id}
          transaction={transaction}
          index={index}
        />
      ))}
    </ScrollView>
  );
};

const styles = StyleSheet.create({
  card: {
    marginBottom: 10,
    borderWidth: 1,
    borderColor: '#dcdcdc',
    padding: 16,
    borderRadius: 8,
  },
  row: {
    flexDirection: 'row',
    justifyContent: 'space-between',
    marginBottom: 10,
    alignItems: 'center',
  },
  text: {
    fontSize: 16,
  },
  chip: {
    marginTop: 5,
    borderRadius: 40,
  },
  link: {
    color: 'blue',
    marginTop: 10,
  },
});
