import React, {useCallback, useEffect, useState} from 'react';
import {Text, View} from 'react-native';
import {ILoan, ILoanTransaction} from '../../typings/loan';
import {useLMS} from '../../context/context';
import {useAppErrors} from '../../hooks';
import {Gutter} from '../../components';
import moment from 'moment';
import {RepaymentTable} from '../components/RepaymentTable';

export const LoanRepayment: React.ComponentType<ILoan> = ({...props}) => {
  const {axiosInstance} = useLMS();
  const [repayments, setRepayments] = useState<ILoanTransaction[]>([]);
  const {setAppError} = useAppErrors();

  const getRepaymentList = useCallback(async () => {
    try {
      const {data} = await axiosInstance.get(
        `/v1/external-lending/sme/loans/${props._id}/transaction`,
      );

      setRepayments(data);
    } catch (e: any) {
      setAppError(e.response.data);
    }
  }, [axiosInstance, props._id, setAppError]);

  useEffect(() => {
    if (props._id) {
      getRepaymentList();
    }
  }, [getRepaymentList, props._id]);

  return (
    <>
      <View
        style={{
          display: 'flex',
          flexDirection: 'column',
          gap: 10,
          paddingTop: 20,
          paddingBottom: 20,
          paddingLeft: 16,
          paddingRight: 16,
        }}>
        <View style={{flexDirection: 'row', justifyContent: 'space-between'}}>
          <Text style={{fontWeight: '600'}}>Amount Repaid:</Text>
          <Text>PKR {props.payments?.principal_repaid?.toLocaleString()}</Text>
        </View>

        <View style={{flexDirection: 'row', justifyContent: 'space-between'}}>
          <Text style={{fontWeight: '600'}}>Amount Due:</Text>
          <Text>
            PKR{' '}
            {(
              (props.pending?.principal || 0) + (props.pending?.markup_fee || 0)
            ).toLocaleString()}
          </Text>
        </View>

        <View style={{flexDirection: 'row', justifyContent: 'space-between'}}>
          <Text style={{fontWeight: '600'}}>Repayment End Date:</Text>
          <Text>
            {props.tenure
              ? moment(props.disbursement_date)
                  .add(props.tenure, 'days')
                  .format('DD/MM/YY')
              : '-'}
          </Text>
        </View>

        {props.pending && props.pending?.late_fees > 0 && (
          <View style={{flexDirection: 'row', justifyContent: 'space-between'}}>
            <Text style={{fontWeight: '600'}}>Late Fee:</Text>
            <Text>{props.pending?.late_fees.toLocaleString()}</Text>
          </View>
        )}
      </View>
      <Gutter />
      <RepaymentTable dataSource={repayments} />
    </>
  );
};
