export interface IFile {
  name: string;
  resourceURL: string;
  size: number;
  verified?: boolean;
}

export enum ContractStatus {
  CONTRACT_VALID = 'contract_valid',
  CONTRACT_EXPIRED = 'contract_expired',
  CONTRACT_PENDING = 'contract_pending',
}

export enum CustomerStatus {
  IN_PROGRESS = 'in_progress',
  APPROVED = 'approved',
  REJECTED = 'rejected',
  PENDING = 'pending',
}

export interface Status {
  status: string;
  timestamp: string;
  updated_by: string; // user_id of LMS personnel
  reason?: string;
  comment?: string;
}

export interface IFacility {
  id: string;
  envelope_id: string;
  envelope_url: string;
  credit_limit?: number;
  markup?: number;
  contract_documents: string[];
  contract_details: any;
  signing_date: string;
  expiry_date: string;
  status: ContractStatus;
  status_history: Status[];
}

export interface IPartnerSnapshot {
  name: string;
  id: string;
  loan_id?: string;
}

export interface ICreditBureauReport extends Record<string, unknown> {
  _id: string;
  keys: string[];
}

export enum TransactionType {
  DISBURSEMENT = 'disbursement',
  REPAYMENT = 'repayment',
  LATE_FEE = 'late_fee',
  MARKUP = 'markup',
}

export enum PaymentMethod {
  BANK_TRANSFER = 'bank_transfer',
  CASH_VIA_FSO = 'cash_via_fso',
  ONE_BILL = 'one_bill',
  ONLINE_CASH_DEPOSIT = 'online_cash_deposit',
  CLEARING_CHEQUE_DEPOSIT = 'clearing_cheque_deposit',
}

export type TransferType =
  | 'bank_transfer'
  | 'cash_via_fso'
  | 'one_bill'
  | 'online_cash_deposit'
  | 'clearing_cheque_deposit';

export type RepaymentType = {
  user_id: string;
  amount: string;
  type: TransactionType;
  method?: TransferType;
  payment_date: string;
  transaction_image?: string;
  maxPayment?: string | number;
};
